%Where is the matthew dataset? Add it to your path first
matt = xlsread('HurricaneMatthew_TSJulia_Prec_Dis.xlsx');

%discharge (ft^3/s)
dis = matt(:,6);

%build date vector between 9/25 - 10/24 in hour increments
newtime = datenum(2016,9,25):1/24:datenum(2016,10,24);
newtime = newtime(1:694);

%Because of the massive flow through lock and dam 1, the operators
%increased their sampling frequency from 4 cph to 10 cph
%during peak output. We account for it here
dis_15 = dis(1:1651);
dis_6 = dis(1652:2947);
dis_15_2 = dis(2948:end);

%Build new time series of hourly averages based on sampling frequency
n = 4;
b = arrayfun(@(i) mean(dis_15(i:i+n-1)),1:n:length(dis_15)-n+1)'; % the averaged vector

n = 10;
c = arrayfun(@(i) mean(dis_6(i:i+n-1)),1:n:length(dis_6)-n+1)'; % the averaged vector

n = 4;
d = arrayfun(@(i) mean(dis_15_2(i:i+n-1)),1:n:length(dis_15_2)-n+1)'; % the averaged vector

dis = vertcat(b,c,d);


y = dis;

%We have a chunk of missing discharge data, so let's interpolate what's
%missing
bd = isnan(y);
gd = find(~bd);
bd([1:(min(gd)-1) (max(gd)+1):end])=0;
y(bd)=interp1(gd,dis(gd),find(bd)); 

%Our new discharge data
dis_new = y;

%compare old and new
plot(dis_new), hold on, plot(dis);

%Bring in the area-averaged precipitation data
precip_avg = matt(:,1);
%find and remove NaNs
precip = precip_avg(all(~isnan(precip_avg),2),:);
precip([695 696]) = [];




%%lag plots 
% lag = [1:1:694];
% 
% n = length(dis_new);

%Here's some code to build a little animation of lag plots. This
%essentially shows how flow patterns are correlated to precipitation x
%hours earlier. Use the variable 'lag' to adjust your lag time. This runs
%pretty slowly on my laptop so beware! May not work with versions later
%than 2013a

% aviobj = VideoWriter('Discharge.avi');
% set(aviobj,'FrameRate',7.5)
% open(aviobj);
% fig = gcf
% parfor i = lag
%     lagged = dis_new((1+i):n);
%     laggedToo = precip(1: (n-i));
%     
%     
%     subplot(2,1,1)
%     f = fit(laggedToo,lagged,'poly1');
%     H = plot(f, laggedToo,lagged);
%     legend('off')
%     ylim manual
%     ylim ([0 70000])
%     set(H,{'MarkerSize'},{6.5});
%     ylabel('Discharge (ft^3/s)','FontSize',12,'FontName','TimesNewRoman');
%     xlabel('Precipitation (kg/m^2)','FontSize',12,'FontName','TimesNewRoman');
%     
%     subplot(2,1,2)
%     
%     [AX,H1,H2] = plotyy(newtime,dis_new,newtime,precip,'plot');
%     set(H1, 'LineWidth',1.25,'Color','blue')
%     set(H2, 'LineWidth',1.25,'Color','red')
%     set(get(AX(1),'Ylabel'),'String','Discharge (ft^3/s)','Color','blue','FontSize',12,'FontName','TimesNewRoman') ;
%     set(get(AX(2),'Ylabel'),'String','Precipitation (kg/m^2)','Color','red','FontSize',12,'FontName','TimesNewRoman');
%     set(AX(2),'ycolor','r');
%     xlabel('Date','FontSize',12,'FontName','TimesNewRoman')
%     datetick(AX(1), 'x', 'mm/dd', 'keepticks', 'keeplimits')
%     datetick(AX(2), 'x', 'mm/dd', 'keepticks', 'keeplimits')
%     L = get(gca,'ylim');
%     hold on
%     NL = plot([newtime(i) newtime(i)],L,'color','b');
%     
%     mov(i) = getframe(fig);
%     writeVideo(aviobj,mov(i))
%     pause(0.5)
%     delete(NL)
% end
% 
% close(aviobj)

%cross correlation plots
[acorr,lag]=xcorr(precip,dis_new,'coef');
figure
plot(lag,acorr,'LineWidth',1.2) 


%separating discharge events - Tropical Storm Julia and Hurricane Matthew
dis_1 = dis_new(50:250);
precip_1 = precip(50:250);

[acorr,lag]=xcorr(dis_1,precip_1,'coef');

dis_2 = dis_new(275:475);
precip_2 = precip(275:475);

[acorr2,lag2] = xcorr(dis_2,precip_2,'coef');
plot(lag2,acorr2);

%plot it out
figure
subplot(2,2,1)
[AX,H1,H2] = plotyy(newtime(1:length(dis_1)),dis_1,newtime(1:length(dis_1)),precip_1,'plot');
    set(H1, 'LineWidth',1.25,'Color','blue')
    set(H2, 'LineWidth',1.25,'Color','red')
    set(get(AX(1),'Ylabel'),'String','Discharge (ft^3/s)','Color','blue','FontSize',12,'FontName','TimesNewRoman') ;
    set(get(AX(2),'Ylabel'),'String','Precipitation (kg/m^2)','Color','red','FontSize',12,'FontName','TimesNewRoman');
    set(AX(2),'ycolor','r');
    datetick(AX(1), 'x', 'mm/dd', 'keepticks', 'keeplimits')
    datetick(AX(2), 'x', 'mm/dd', 'keepticks', 'keeplimits')

subplot(2,2,2)
plot(lag,acorr,'LineWidth',1.2)
ylabel('Correlation','FontSize',12,'FontName','TimesNewRoman')
xlabel('Lag (hr)','FontSize',12,'FontName','TimesNewRoman')
xlim([100 150])
ylim([0.25 0.6])

subplot(2,2,3)
[AX,H1,H2] = plotyy(newtime(275:475),dis_2,newtime(275:475),precip_2,'plot');
    set(H1, 'LineWidth',1.25,'Color','blue')
    set(H2, 'LineWidth',1.25,'Color','red')
    set(get(AX(1),'Ylabel'),'String','Discharge (ft^3/s)','Color','blue','FontSize',12,'FontName','TimesNewRoman') ;
    set(get(AX(2),'Ylabel'),'String','Precipitation (kg/m^2)','Color','red','FontSize',12,'FontName','TimesNewRoman');
    set(AX(2),'ycolor','r');
    datetick(AX(1), 'x', 'mm/dd', 'keepticks', 'keeplimits')
    datetick(AX(2), 'x', 'mm/dd', 'keepticks', 'keeplimits')

subplot(2,2,4)
plot(lag2,acorr2,'LineWidth',1.2)
ylabel('Correlation','FontSize',12,'FontName','TimesNewRoman')
xlabel('Lag (hr)','FontSize',12,'FontName','TimesNewRoman')
xlim([100 150])
ylim([0.25 0.6])


%max cor occurs at lag = 105 hours



%plot everything
figure
[AX,H1,H2] = plotyy(newtime,dis_new,newtime,precip,'plot');
    set(H1, 'LineWidth',1.25,'Color','blue')
    set(H2, 'LineWidth',1.25,'Color','red')
    set(get(AX(1),'Ylabel'),'String','Discharge (ft^3/s)','Color','blue','FontSize',12,'FontName','TimesNewRoman') ;
    set(get(AX(2),'Ylabel'),'String','Precipitation (kg/m^2)','Color','red','FontSize',12,'FontName','TimesNewRoman');
    set(AX(2),'ycolor','r');
    datetick(AX(1), 'x', 'mm/dd', 'keepticks', 'keeplimits')
    datetick(AX(2), 'x', 'mm/dd', 'keepticks', 'keeplimits')
   
    